plotting function for indicators with reference points for 30 years consistent with climate data using +/- 0.5 SD
Source:R/plot_indicator_ref_period_halfsd.R
plot_indicator_ref_period_halfsd.Rdplotting function for indicators with reference points for 30 years consistent with climate data using +/- 0.5 SD